@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 from tastypie import fields
 from tastypie.resources import ModelResource
 from .models import Author, Post, Media
@@ -8,7 +10,7 @@ class AuthorResource(ModelResource):
 
     class Meta:
         queryset = Author.objects.all()
-        resource_name = 'author'
+        resource_name = u'author'
         filtering = {
             'age': ('exact',),
             'name': ('exact',),
@@ -19,14 +21,15 @@ class PostResource(ModelResource):
     author = fields.ForeignKey(AuthorResource, attribute='author', null=True)
     files = fields.ManyToManyField('tests.api.MediaResource', attribute='files')
     date = fields.DateTimeField('date')
+    rating = fields.DecimalField('rating', null=True)
 
     class Meta:
         queryset = Post.objects.all()
-        resource_name = 'post'
+        resource_name = u'post'
 
 
 class MediaResource(ModelResource):
     class Meta:
         queryset = Media.objects.all()
-        resource_name = 'media'
+        resource_name = u'media'
 
